// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KADDRESSBOOKIMPORTEXPORT_VERSION_H
#define KADDRESSBOOKIMPORTEXPORT_VERSION_H

#define KADDRESSBOOKIMPORTEXPORT_VERSION_STRING "6.7.0"
#define KADDRESSBOOKIMPORTEXPORT_VERSION_MAJOR 6
#define KADDRESSBOOKIMPORTEXPORT_VERSION_MINOR 7
#define KADDRESSBOOKIMPORTEXPORT_VERSION_PATCH 0
#define KADDRESSBOOKIMPORTEXPORT_VERSION ((6<<16)|(7<<8)|(0))

#endif
